==> org-lsst-ccs-ui-3.6.0-sources.jar: org/lsst/ccs/gconsole/base/filter/Versions.java <==
package org.lsst.ccs.gconsole.base.filter;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.lsst.ccs.gconsole.annotations.services.persist.Create;
import org.lsst.ccs.gconsole.services.aggregator.AgentChannel;

/**
 * Filter that selects subsystem state channels.
 *
 * @author onoprien
 */
public class Versions extends AbstractChannelsFilter {

// -- Fields : -----------------------------------------------------------------
    
    private final Pattern pat = Pattern.compile("([^/]+)/+ccsVersions/+([^/]+)/version");

// -- Life cycle : -------------------------------------------------------------
    
    @Create(category = "AgentChannelsFilter",
            name = "Versions",
            path = "Built-In/Versions",
            description = "Channels filter that selects software versions channels.")
    public Versions() {
    }
    
// -- Implementing filter : ----------------------------------------------------

    @Override
    public String getDisplayPath(String originPath) {
        Matcher m = pat.matcher(originPath);
        if (m.matches()) {
            return m.group(1) +"/"+ m.group(2);
        } else {
            return null;
        }
    }

    @Override
    public String getOriginPath(String displayPath) {
        String[] ss = displayPath.split("/");
        return ss.length == 2 ? ss[0] +"/ccsVersions/"+ ss[1] +"/version" : null;
    }

    @Override
    public List<String> getOriginChannels() {
        return Collections.singletonList("/ccsVersions/");
    }

    @Override
    public List<String> getFields(boolean compact) {
        return compact ? 
                Collections.singletonList(AgentChannel.Key.VALUE) : 
//                Arrays.asList(new String[] {AgentChannel.Key.VALUE, "org.lsst.ccs.agent.hostname"});
                Arrays.asList(new String[] {AgentChannel.Key.VALUE, "HOST"});
    }

}

==> org-lsst-ccs-ui-4.1.2-20220126.152835-1-sources.jar: org/lsst/ccs/gconsole/base/filter/Versions.java <==
package org.lsst.ccs.gconsole.base.filter;

import java.util.*;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.lsst.ccs.gconsole.annotations.services.persist.Create;
import org.lsst.ccs.gconsole.services.aggregator.AgentChannel;

/**
 * Filter that selects subsystem state channels.
 *
 * @author onoprien
 */
public class Versions extends AbstractChannelsFilter {

// -- Fields : -----------------------------------------------------------------
    
    static public final String CREATOR_PATH = "Built-In/Special/Versions";
    
    private final Pattern pat = Pattern.compile("([^/]+)/+ccsVersions/+([^/]+)/version");

// -- Life cycle : -------------------------------------------------------------
    
    @Create(category = AgentChannelsFilter.CATEGORY,
            name = "Versions",
            path = CREATOR_PATH,
            description = "Channels filter that selects software versions channels.")
    public Versions() {
    }
    
// -- Implementing filter : ----------------------------------------------------

    @Override
    public String getDisplayPath(String originPath) {
        Matcher m = pat.matcher(originPath);
        if (m.matches()) {
            return m.group(1) +"/"+ m.group(2);
        } else {
            return null;
        }
    }

    @Override
    public String getOriginPath(String displayPath) {
        String[] ss = displayPath.split("/");
        return ss.length == 2 ? ss[0] +"/ccsVersions/"+ ss[1] +"/version" : null;
    }

    @Override
    public List<String> getOriginChannels() {
        return Collections.singletonList("/ccsVersions/");
    }

    @Override
    public List<String> getFields(boolean compact) {
        return compact ? 
                Collections.singletonList(AgentChannel.Key.VALUE) : 
                Arrays.asList(new String[] {AgentChannel.Key.VALUE, "HOST"});
    }

    @Override
    public String getName() {
        return "Versions";
    }

}
